"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SessionStorageGateway = void 0;
var _Session = require("../entities/Session");
var _global = require("../global");
class SessionStorageGateway {
  constructor(storage, httpClient, ws) {
    this.storage = storage;
    this.httpClient = httpClient;
    this.ws = ws;
  }
  async sendAction(action) {
    const sessionId = await this.getCurrent();
    await this.httpClient.post('/webchat/action', {
      botId: _global.Global.botId,
      action,
      sessionId
    });
  }
  async subscribe(sessionId) {
    const response = await this.httpClient.post('/webchat/subscribe', {
      sessionId,
      botId: _global.Global.botId,
      parameters: JSON.stringify(_global.Global.params),
      socketId: _global.Global.socketId
    });
    this.changeSession(response.sessionId);
    return new _Session.Session(response.sessionId);
  }
  async getCurrent() {
    const sessionId = await this.storage.retrieve('sessionId');
    return sessionId || '';
  }
  async changeSession(newSessionId) {
    await this.storage.store('sessionId', newSessionId);
    return newSessionId;
  }
  async clearSession() {
    const session = '';
    await this.storage.store('sessionId', session);
    return new _Session.Session(session);
  }
  async linkSession() {
    const sessionId = await this.storage.retrieve('sessionId');
    this.ws.sendMessage({
      action: 'link',
      data: {
        sessionId,
        botId: _global.Global.botId
      }
    });
  }
  async onEndConversation(callback) {
    this.ws.onEndConversation(callback);
  }
}
exports.SessionStorageGateway = SessionStorageGateway;
//# sourceMappingURL=SessionStorageGateway.js.map