import { MessageTypes } from '../types';
import { MessageList } from '../entities/MessageList';
import { channel } from '../constants';
import { Global } from '../global';
export class MessageHttpSocketGateway {
  constructor(ws, httpConnection, storage, sessionGateway) {
    this.ws = ws;
    this.httpConnection = httpConnection;
    this.storage = storage;
    this.sessionGateway = sessionGateway;
  }
  async sendStatus(messageId, status) {
    const sessionId = await this.sessionGateway.getCurrent();
    const payload = {
      sessionId,
      botId: Global.botId,
      status,
      messageId
    };
    await this.httpConnection.post('/webchat/status', payload);
  }
  async getMessages() {
    const messages = await this.storage.retrieve('messages');
    return new MessageList(JSON.parse(messages));
  }
  async sendMessage(msg) {
    const messagesData = JSON.parse((await this.storage.retrieve('messages')) || '[]');
    messagesData.push(msg);
    await this.storage.store('messages', JSON.stringify(messagesData));
    const sessionId = await this.sessionGateway.getCurrent();
    if (!sessionId) {
      await this.sessionGateway.subscribe('');
    } else {
      this.httpConnection.post('/webchat/message', {
        botId: Global.botId,
        message: msg.message,
        isMedia: msg.type !== MessageTypes.TEXT,
        ext: msg.ext,
        sessionId: sessionId,
        botChannel: channel,
        isPreview: false,
        socketId: Global.socketId
      });
    }
    return new MessageList(messagesData);
  }
  async storeMessage(msg) {
    const messages = JSON.parse((await this.storage.retrieve('messages')) || '[]');
    messages.push(msg);
    await this.storage.store('messages', JSON.stringify(messages));
    return new MessageList(messages);
  }
  async clearMessages() {
    const messageList = [];
    await this.storage.store('messages', JSON.stringify(messageList));
    return new MessageList(messageList);
  }
  onMessage(callback) {
    this.ws.onMessage(callback);
  }
}
//# sourceMappingURL=MessageHttpSocketGateway.js.map