import { Session } from '../entities/Session';
import { Global } from '../global';
export class SessionStorageGateway {
  constructor(storage, httpClient, ws) {
    this.storage = storage;
    this.httpClient = httpClient;
    this.ws = ws;
  }
  async sendAction(action) {
    const sessionId = await this.getCurrent();
    await this.httpClient.post('/webchat/action', {
      botId: Global.botId,
      action,
      sessionId
    });
  }
  async subscribe(sessionId) {
    const response = await this.httpClient.post('/webchat/subscribe', {
      sessionId,
      botId: Global.botId,
      parameters: JSON.stringify(Global.params),
      socketId: Global.socketId
    });
    this.changeSession(response.sessionId);
    return new Session(response.sessionId);
  }
  async getCurrent() {
    const sessionId = await this.storage.retrieve('sessionId');
    return sessionId || '';
  }
  async changeSession(newSessionId) {
    await this.storage.store('sessionId', newSessionId);
    return newSessionId;
  }
  async clearSession() {
    const session = '';
    await this.storage.store('sessionId', session);
    return new Session(session);
  }
  async linkSession() {
    const sessionId = await this.storage.retrieve('sessionId');
    this.ws.sendMessage({
      action: 'link',
      data: {
        sessionId,
        botId: Global.botId
      }
    });
  }
  async onEndConversation(callback) {
    this.ws.onEndConversation(callback);
  }
}
//# sourceMappingURL=SessionStorageGateway.js.map