import React from 'react';
import { KeyboardAvoidingView, Platform } from 'react-native';
import App from './App';
import { Global } from './global';
import { getEnvironment } from './utils';
import { AxiosHttpConnectionAdapter, WebSocketAdapter, ConsoleLoggerAdapter, EncryptedStorageAdapter, MathUuidAdapter } from './infra';
import { MessageHttpSocketGateway } from './gateways/MessageHttpSocketGateway';
import { ChatConfigurationsHttpGateway } from './gateways/ChatConfigurationsHttpGateway';
import { SessionStorageGateway } from './gateways/SessionStorageGateway';
import UuidContextProvider from './context/UuidContext';
import { SocketConnectionProvider, ChatConfigurationsProvider, MessageListProvider, SessionProvider } from './providers';
export const Code7Boteria = _ref => {
  let {
    botId,
    params,
    appearance,
    children,
    staging
  } = _ref;
  const env = getEnvironment(staging);
  Global.botId = botId;
  Global.params = params;
  Global.env = env;
  const logger = new ConsoleLoggerAdapter();
  const wsAdapter = new WebSocketAdapter(env.SOCKET_URL, logger);
  const axiosAdapterApi = new AxiosHttpConnectionAdapter(env.API_URL, logger);
  const axiosAdapterGetBot = new AxiosHttpConnectionAdapter(env.GET_BOT_URL, logger);
  const chatConfigurationsGateway = new ChatConfigurationsHttpGateway(axiosAdapterGetBot);
  const storage = new EncryptedStorageAdapter();
  const sessionGateway = new SessionStorageGateway(storage, axiosAdapterApi, wsAdapter);
  const messageGateway = new MessageHttpSocketGateway(wsAdapter, axiosAdapterApi, storage, sessionGateway);
  const uuidAdapter = new MathUuidAdapter();
  return /*#__PURE__*/React.createElement(KeyboardAvoidingView, {
    behavior: Platform.OS === 'ios' ? 'padding' : 'height'
  }, /*#__PURE__*/React.createElement(UuidContextProvider, {
    uuid: uuidAdapter
  }, /*#__PURE__*/React.createElement(SocketConnectionProvider, {
    ws: wsAdapter
  }, /*#__PURE__*/React.createElement(ChatConfigurationsProvider, {
    configurations: chatConfigurationsGateway,
    appearance: appearance
  }, /*#__PURE__*/React.createElement(SessionProvider, {
    sessionGateway: sessionGateway
  }, /*#__PURE__*/React.createElement(MessageListProvider, {
    messageGateway: messageGateway
  }, /*#__PURE__*/React.createElement(App, {
    customWidget: children
  })))))));
};
//# sourceMappingURL=index.js.map